<?php

namespace Ovr\Forms\Policies;

use Litepie\User\Contracts\UserPolicy;
use Ovr\Forms\Models\CashPurchase;

class CashPurchasePolicy
{

    /**
     * Determine if the given user can view the cash_purchase.
     *
     * @param UserPolicy $user
     * @param CashPurchase $cash_purchase
     *
     * @return bool
     */
    public function view(UserPolicy $user, CashPurchase $cash_purchase)
    {
        if ($user->canDo('forms.cash_purchase.view') && $user->isAdmin()) {
            return true;
        }

        return $cash_purchase->user_id == user_id() && $cash_purchase->user_type == user_type();
    }

    /**
     * Determine if the given user can create a cash_purchase.
     *
     * @param UserPolicy $user
     * @param CashPurchase $cash_purchase
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('forms.cash_purchase.create');
    }

    /**
     * Determine if the given user can update the given cash_purchase.
     *
     * @param UserPolicy $user
     * @param CashPurchase $cash_purchase
     *
     * @return bool
     */
    public function update(UserPolicy $user, CashPurchase $cash_purchase)
    {
        if ($user->canDo('forms.cash_purchase.edit') && $user->isAdmin()) {
            return true;
        }

        return $cash_purchase->user_id == user_id() && $cash_purchase->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given cash_purchase.
     *
     * @param UserPolicy $user
     * @param CashPurchase $cash_purchase
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, CashPurchase $cash_purchase)
    {
        return $cash_purchase->user_id == user_id() && $cash_purchase->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given cash_purchase.
     *
     * @param UserPolicy $user
     * @param CashPurchase $cash_purchase
     *
     * @return bool
     */
    public function verify(UserPolicy $user, CashPurchase $cash_purchase)
    {
        if ($user->canDo('forms.cash_purchase.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given cash_purchase.
     *
     * @param UserPolicy $user
     * @param CashPurchase $cash_purchase
     *
     * @return bool
     */
    public function approve(UserPolicy $user, CashPurchase $cash_purchase)
    {
        if ($user->canDo('forms.cash_purchase.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
